@@ -2,6 +2,7 @@
 
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![allow(clippy::missing_safety_doc)]
+#![allow(clippy::manual_c_str_literals)]
 #![doc = include_str!("../README.md")]
 
 pub use gst;
@@ -21,6 +22,8 @@ macro_rules! assert_initialized_main_thread {
 }
 
 #[allow(clippy::needless_borrow)]
+#[allow(unused)]
+#[allow(unused_imports)]
 mod auto;
 pub(crate) use crate::auto::PlayMessage as PlayMessageType;
 pub use crate::auto::*;
@@ -37,7 +40,7 @@ mod play_signal_adapter;
 mod play_video_overlay_video_renderer;
 mod play_visualization;
 
-mod play_message;
+pub mod play_message;
 pub use crate::play_message::PlayMessage;
 
 // Re-export all the traits in a prelude module, so that applications
